# ResilienceCurves

In this subpackage all logic is found regarding reading and using resilience curves.
The resilience curves are read from a CSV defined in `AnalysisConfigData.AnalysisSectionLosses.resilience_curves_file`.